import sys
import java

AdminControl = None
AdminConfig = None
AdminApp = None

LINE_SEPARATOR=java.lang.System.getProperty("line.separator")

def toArray(list, sep=LINE_SEPARATOR):
    array = []
    if (list != ""):
        array = list.split(sep)
    return array

def getId(cell, node, server=None, type=None, name=None):
    id = ''
    if cell:
      id = '/Cell:' + cell
    if node:
      id = id + '/Node:' + node
    if server:
      id = id + '/Server:' + server
    if type:
      id = id + '/' + type + ':'
      if name:
        id = id + name
    if id:
      id = id + '/'
    return AdminConfig.getid(id)

def getCell():
    cells=AdminConfig.list('Cell')
    fullCell=cells.split(LINE_SEPARATOR)[0]
    cell=AdminConfig.showAttribute(fullCell,'name')
    return cell

def getNames(list):
    namesList=[]
    for fullItem in toArray(list):
	item=AdminConfig.showAttribute(fullItem,'name')
	namesList.append(item)
    return namesList


def getCells():
    cells=AdminConfig.list('Cell')
    return getNames(cells)

def getNode(cell):
    scopeId=AdminConfig_getid('/Cell:'+cell+'/')
    fullNode=AdminConfig_list('Node',scopeId)[0]
    node=AdminConfig.showAttribute(fullNode,'name')
    return node

def getNodes(cell):
    scopeId=AdminConfig_getid('/Cell:'+cell+'/')
    nodes=AdminConfig.list('Node',scopeId)
    return getNames(nodes)


def getServers(cell,node):
    scopeId=AdminConfig_getid('/Cell:'+cell+'/Node:'+node+'/')
    servers=AdminConfig.list('Server',scopeId)
    return getNames(servers)

def AdminConfig_getid(id):
    return AdminConfig.getid(id)

def AdminConfig_list(type, id):
    if not id:
        return []
    return toArray(AdminConfig.list(type, id))

def AdminConfig_listTemplates(templateType, templateName):
    return toArray(AdminConfig.listTemplates(templateType, templateName))

def findTemplate(templateType, attrName, templateName):
    templates = AdminConfig_listTemplates(templateType, templateName)
    for template in templates:
      if (AdminConfig.showAttribute(template, attrName) == templateName):
        return template
    return None

def AdminConfig_showAttribute(id, attr):
    if not id:
        return []
    val = AdminConfig.showAttribute(id, attr)
    if not val:
        return []
    if (val[0] != '['):
        return [val]
    return toArray(val[1:-1], ' ')

def find(scopeId, type, attrName = None, attrValue = None):
    rc = 0
    ids = AdminConfig_list(type, scopeId)
    for id in ids:
      if attrName:
        if (AdminConfig.showAttribute(id, attrName) != attrValue):
          id = None
      if id:
		return id
    return None

def remove(scopeId, type, attrName = None, attrValue = None):
    rc = 0
    ids = AdminConfig_list(type, scopeId)
    for id in ids:
      if attrName:
        if (AdminConfig.showAttribute(id, attrName) != attrValue):
          id = None
      if id:
        AdminConfig.remove(id)
        rc = 1
    return rc


def _print(file, str='', terminator='\n'):
    file.write(str+terminator)

def print_exc(file=None, limit=None):
    etype, value, tb = sys.exc_info()
    if file is None:
        file = sys.stderr
    if tb:
        n=0
        print 'Traceback (most recent call last:)'
        while tb is not None and (limit is None or n < limit):
            f = tb.tb_frame
            lineno = tb.tb_lineno
            co = f.f_code
            filename = co.co_filename
            name = co.co_name
            _print(file,
               '  File "%s", line %d, in %s' % (filename,lineno,name))
            #line = linecache.getline(filename, lineno)
            #if line: _print(file, '    ' + line.strip())
            tb = tb.tb_next
            n = n+1
    if value is None:
        _print(file, str(etype))
    else:
        _print(file, '%s: %s\n' % (str(etype), value))

def installApp(cell, node, server, appName, earName):
   appOptions = ['-node', node, '-server', server, '-nodeployejb', '-appname', appName]
   AdminApp.install(earName, appOptions)
   return appName

def updateApp(cell, node, server, appName, earName):
   appOptions = ['-operation update -contents \"'+earName+'\" -usedefaultbindings -nodeployejb']
   AdminApp.update(appName,'app',appOptions)
   return appName

def uninstallApp(appName, failonerror='false'):
   global AdminApp

   find = 'false'
   apps = toArray(AdminApp.list())
   for app in apps:
      if app == appName:
         find = 'true'
         break

   if find=='true':
      AdminApp.uninstall(appName)
   else:
      if failonerror == 'true':
         raise Exception, "Application " + appName + " is not installed"
      else:
         print "Warning: Application " + appName + " is not installed"




def checkAppIsInstalled(appName):
   return AdminControl.completeObjectName('type=Application,name='+appName+',*');

def createJAAS(cell, alias, description, username, password):
   sec = AdminConfig.getid("/Cell:" + cell + "/Security:/")
   #
   # Create a JAASAuthData object
   #
   aliasAttr = ["alias", alias]
   descAttr = ["description", description]
   useridAttr = ["userId", username]
   passwordAttr = ["password", password]
   attrs = [aliasAttr, descAttr, useridAttr, passwordAttr]

   appauthdata = find(sec, 'JAASAuthData', 'alias', alias)
   if appauthdata:
      AdminConfig.modify(appauthdata, attrs)
   else:
      appauthdata = AdminConfig.create("JAASAuthData", sec, attrs)

#-----------------------------------------
#
# create
#
#    a very simple WM creation
#
#-----------------------------------------
def createWorkManager(cell, node, server, name, description, jndiname, minthreads, maxthreads, alarmthreads, threadpriority, category='', servicenames='', growable='true'):
   serverId = getId(cell, node, server)
   if not serverId:
      raise Exception, "Server not found"
   workManagerProviders = AdminConfig_list("WorkManagerProvider", serverId)
   workManagerProvider = workManagerProviders[0]
   attrs = []
   attrs.append(['name', name])
   attrs.append(['category', category])
   attrs.append(['description', description])
   attrs.append(['isGrowable', growable])
   attrs.append(['jndiName', jndiname])
   attrs.append(['serviceNames', servicenames])
   attrs.append(['maxThreads', maxthreads])
   attrs.append(['minThreads', minthreads])
   attrs.append(['threadPriority', threadpriority])
   attrs.append(['numAlarmThreads', alarmthreads])
   AdminConfig.create('WorkManagerInfo', workManagerProvider, attrs)

def createJDBCProvider(cell, node, server, templateName, jdbcname):
   #
   # Get the config id for the JDBC Template
   #
   template = findTemplate("JDBCProvider", 'name', templateName)
   if template:
         attrs = []
         attrs.append(['name', jdbcname])
         serverId = getId(cell, node, server)
         newProvider = AdminConfig.createUsingTemplate("JDBCProvider", serverId, attrs, template)
         remove(newProvider, 'DataSource', 'provider', newProvider)
         remove(newProvider, 'WAS40DataSource', 'provider', newProvider)
   return newProvider

#-----------------------------------------
#
# create
#
#    a very simple Data Source creation
#
#-----------------------------------------
def createDataSource(cell, node, server, templateName, jdbcProviderId, dsname, description, jndiname, jaasalias, dbname, dbserver, dbport):
   template = findTemplate("DataSource", 'name', templateName)
   if not template:
     print 'No template found for' + templateName
     raise Exception, "Template not found"

   #
   # start with the creation of the basic attributes
   #
   attrs = []
   attrs.append(['name', dsname])
   attrs.append(['jndiName', jndiname])
   attrs.append(['description', description])
   attrs.append(['authDataAlias', jaasalias])
   #
   # JAAS container-based auth
   #
   mapAttrs = []
   mapAttrs.append(['authDataAlias', jaasalias])
   mapAttrs.append(['mappingConfigAlias', 'DefaultPrincipalMapping'])
   attrs.append(['mapping', mapAttrs])

   #
   # create the data source!
   #
   if jdbcProviderId:
      dataSource = AdminConfig.createUsingTemplate('DataSource', jdbcProviderId, attrs, template)
      if dataSource:
         newProps = {'databaseName': dbname, 'portNumber': dbport, 'serverName': dbserver, 'deferPrepares': 'false', 'driverType': '4'}
         propSet = AdminConfig_showAttribute(dataSource, 'propertySet')
         propSet = AdminConfig_showAttribute(propSet[0], 'resourceProperties')
         for prop in propSet:
           propName = AdminConfig.showAttribute(prop, 'name')
           propValue = newProps.get(propName,)
           if propValue:
               AdminConfig.modify(prop, [['value', propValue]])

         #
         # Connection Pool
         #

         connPool = AdminConfig.showAttribute(dataSource, 'connectionPool')
         AdminConfig.modify(connPool, [['maxConnections','100']])

         #
         # Relational resource adapter
         #
         rra = getId(cell, node, server, 'J2CResourceAdapter', 'WebSphere Relational Resource Adapter')
         rraAttr = ['relationalResourceAdapter', rra]
         attrs = [rraAttr]
         AdminConfig.modify(dataSource, attrs)

         #
         # CMPConnectorFactory
         #
         template = findTemplate("CMPConnectorFactory", 'name', 'CMPConnectorFactory')
         cmpname = dsname + '_CF'
         mapAttrs = []
         mapAttrs.append(['authDataAlias', jaasalias])
         mapAttrs.append(['mappingConfigAlias', 'DefaultPrincipalMapping'])
         attrs = []
         attrs.append(['name', cmpname])
         attrs.append(['authMechanismPreference', 'BASIC_PASSWORD'])
         attrs.append(['authDataAlias', jaasalias])
         attrs.append(['cmpDatasource', dataSource])
         attrs.append(['mapping', mapAttrs])
         newcf = AdminConfig.createUsingTemplate('CMPConnectorFactory', rra, attrs, template)


#-----------------------------------------
#
# create
#
#    a very simple Data Source creation for Oracle
#
#-----------------------------------------
def createOracleDataSource(cell, node, server, templateName, jdbcProviderId, dsname, description, jndiname, jaasalias, dbname, dbserver, dbport):
   template = findTemplate("DataSource", 'name', templateName)
   if not template:
     print 'No template found for' + templateName
     raise Exception, "Template not found"

   #
   # start with the creation of the basic attributes
   #
   attrs = []
   attrs.append(['name', dsname])
   attrs.append(['jndiName', jndiname])
   attrs.append(['description', description])
   attrs.append(['authDataAlias', jaasalias])
   #
   # JAAS container-based auth
   #
   mapAttrs = []
   mapAttrs.append(['authDataAlias', jaasalias])
   mapAttrs.append(['mappingConfigAlias', 'DefaultPrincipalMapping'])
   attrs.append(['mapping', mapAttrs])

   #
   # create the data source!
   #
   if jdbcProviderId:
      dataSource = AdminConfig.createUsingTemplate('DataSource', jdbcProviderId, attrs, template)
      if dataSource:
         newProps = {'URL': 'jdbc:oracle:oci:@' + dbname, 'databaseName': dbname, 'portNumber': dbport, 'serverName': dbserver, 'deferPrepares': 'false', 'driverType': '4'}
         propSet = AdminConfig_showAttribute(dataSource, 'propertySet')
         propSet = AdminConfig_showAttribute(propSet[0], 'resourceProperties')
         for prop in propSet:
           propName = AdminConfig.showAttribute(prop, 'name')
           propValue = newProps.get(propName,)
           if propValue:
               AdminConfig.modify(prop, [['value', propValue]])

         #
         # Connection Pool
         #

         connPool = AdminConfig.showAttribute(dataSource, 'connectionPool')
         AdminConfig.modify(connPool, [['maxConnections','100']])

         #
         # Relational resource adapter
         #
         rra = getId(cell, node, server, 'J2CResourceAdapter', 'WebSphere Relational Resource Adapter')
         rraAttr = ['relationalResourceAdapter', rra]
         attrs = [rraAttr]
         AdminConfig.modify(dataSource, attrs)

         #
         # CMPConnectorFactory
         #
         template = findTemplate("CMPConnectorFactory", 'name', 'CMPConnectorFactory')
         cmpname = dsname + '_CF'
         mapAttrs = []
         mapAttrs.append(['authDataAlias', jaasalias])
         mapAttrs.append(['mappingConfigAlias', 'DefaultPrincipalMapping'])
         attrs = []
         attrs.append(['name', cmpname])
         attrs.append(['authMechanismPreference', 'BASIC_PASSWORD'])
         attrs.append(['authDataAlias', jaasalias])
         attrs.append(['cmpDatasource', dataSource])
         attrs.append(['mapping', mapAttrs])
         newcf = AdminConfig.createUsingTemplate('CMPConnectorFactory', rra, attrs, template)



def testDataSource(cell, node, server, jdbcProvider, dsname):
   dataSource = getId(cell, node, server, 'JDBCProvider:' + jdbcProvider +'/DataSource', dsname)
   if dataSource:
      return AdminControl.testConnection(dataSource)

def createLibrary(cell, node, libraryName, classpath):
    npath = "/Cell:"+cell+"/Node:"+node+"/"
    lpath = npath+"Library:" + libraryName
    libraryId = AdminConfig_getid(lpath)

    libraryId = find(libraryId, 'Library', 'name', libraryName)
    if libraryId:
       print "Found library: " + libraryName
    else:
       print "Creating library: " + libraryName
       nodeId = AdminConfig_getid(npath)
       libraryId = AdminConfig.create('Library', nodeId, [['name', libraryName], ['classPath',  classpath]])
    return libraryId

def removeLibrary(cell, node, libraryName):
    npath = "/Cell:"+cell+"/Node:"+node+"/"
    lpath = npath+"Library:"+libraryName
    libraryId = AdminConfig.getid(lpath)
    rc = remove(libraryId, 'Library', 'name', libraryName)
    if rc:
       print "Removed library: " + libraryName
    else:
       print "Library does not exist: " + libraryName



def createServerClassloader(appServer, libraryName, classloaderMode):
    # find the library
    found = 0;
    classLoaders = AdminConfig_showAttribute(appServer, 'classloaders')
    for cloader in classLoaders:
        libraries = AdminConfig_showAttribute(cloader, 'libraries')
        for library in libraries:
            if (AdminConfig.showAttribute(library, 'libraryName') == libraryName):
                found = 1
                break
        if found:
            break
    else:
        classLoader = AdminConfig.create('Classloader', appServer, [['mode',  classloaderMode]])
        AdminConfig.create('LibraryRef', classLoader, [['libraryName', libraryName],  ['sharedClassloader', 'false']])

def createApplicationClassloader(appDeployment, libraryName, classloaderMode):
    # find the library
    found = 0;
    classLoader = AdminConfig.showAttribute(appDeployment, 'classloader')
    if not classLoader:
        classLoader = AdminConfig.create('Classloader', appDeployment, [['mode',  classloaderMode]])
    else:
        AdminConfig.modify(classLoader, [['mode',  classloaderMode]])
    libraries = AdminConfig_showAttribute(classLoader, 'libraries')
    for library in libraries:
        if (AdminConfig.showAttribute(library, 'libraryName') == libraryName):
            break
    else:
        AdminConfig.create('LibraryRef', classLoader, [['libraryName', libraryName],  ['sharedClassloader', 'false']])

def createClassloader(cell, node, server, application, libraryName, classloaderMode):
    if server:
        print "creating Application Server classloader"
        serverId = AdminConfig.getid("/Cell:"+cell+"/Node:"+node+"/Server:"+server+"/")
        if not serverId:
            raise Exception, "Invalid server name"
        cloaderParent = AdminConfig.list('ApplicationServer', serverId)
        createServerClassloader(cloaderParent, libraryName, classloaderMode)
    elif application:
        print "creating Application classloader"
        deployment = AdminConfig.getid('/Deployment:' + application + '/')
        if not deployment:
            raise Exception, "Invalid application name"
        cloaderParent = AdminConfig.showAttribute(deployment, 'deployedObject')
        createApplicationClassloader(cloaderParent, libraryName, classloaderMode)
    else:
        raise Exception, "Application or server must be defined"

def removeClassloader(cell, node, server, application, libraryName, failonerror='false'):
    global AdminConfig

    cloaderParent=None

    if server:
        print "removing Application Server classloader"
        serverId = AdminConfig.getid("/Cell:"+cell+"/Node:"+node+"/Server:"+server+"/")
        if not serverId:
            raise Exception, "Invalid server name"
        cloaderParent = AdminConfig.list('ApplicationServer', serverId)
        cloaderAttr = 'classloaders'

    elif application:
        print "removing Application classloader"
        cloaderAttr = 'classloader'
        deployment  = AdminConfig.getid('/Deployment:' + application + '/')

        if deployment:
            cloaderParent = AdminConfig.showAttribute(deployment, 'deployedObject')            
        else:
            if failonerror == 'true':
                raise Exception, "Unable to find application " + application 
            else:
                print "Warning: Unable to find application " + application

    else:
        raise Exception, "Application or server must be defined"

    # find the library
    if cloaderParent:
        classLoaders = AdminConfig_showAttribute(cloaderParent, cloaderAttr)
        for cloader in classLoaders:
            libraries = AdminConfig_showAttribute(cloader, 'libraries')
            for library in libraries:
                lname = AdminConfig.showAttribute(library, 'libraryName')
                if (lname == libraryName):
                    AdminConfig.remove(library)
            libraries = AdminConfig_showAttribute(cloader, 'libraries')
            if len(libraries) == 0:
                AdminConfig.remove(cloader)    # remove empty classloaders
    else:
      if failonerror == 'true':
         raise Exception, "Unable to remove " + libraryName
      else:
         print "Warning: Library " + libraryName + " not available"



def setVariable(cell, node, server, varName, varValue):
    varMapId = getId(cell, node, server, 'VariableMap')
    varEntries = AdminConfig_list('VariableSubstitutionEntry', varMapId)
    for varEntry in varEntries:
      if (AdminConfig.showAttribute(varEntry, 'symbolicName') == varName):
        attributeList = '[[value "' + varValue + '"]]'
        print 'Updating variable %s' % varName
        AdminConfig.modify(varEntry, attributeList)
        break
    else:
        attributeList = '[value "' + varValue +'"]'
        print 'Creating variable %s' % varName
        AdminConfig.create('VariableSubstitutionEntry', varMapId, [['symbolicName', varName], attributeList])


def createSSLConfig(configName, keyStore, keyPassword, trustStore, trustPassword, certDir, auth='false'):
   #--------------------------------------------------------------
   # set up globals
   #--------------------------------------------------------------
   global AdminConfig

   sec = AdminConfig.getid("/Cell:/Security:/")
   print "security id = " + sec

   ssl = find(sec, 'SSLConfig', 'alias', configName)
   if ssl:
      print 'SSL Configuration already created, nothing to do'
      return ssl
    
   sslConfig=[['keyFileName', certDir + '/' + keyStore],
             ['keyFilePassword',keyPassword], ['keyFileFormat','JKS'],
             ['trustFileName',certDir + '/' + trustStore],
             ['trustFilePassword',trustPassword], ['trustFileFormat','JKS'],
             ['clientAuthentication',auth], ['securityLevel','HIGH'],
             ['enableCryptoHardwareSupport', 'false'],
             ['properties', [[['name', 'com.ibm.ssl.protocol'],['value', 'SSL']],[['name','com.ibm.ssl.contextProvider'],['value','IBMJSSE2']]]]]

   return AdminConfig.create("SSLConfig", sec, [['alias', configName], ['setting', sslConfig]], 'repertoire')



def createSecureChannelChain(appServerID, TCPChannelName, SSLChannelName, HTTPChannelName, WebContainerChannelName, chainName, sslProfileName, endpointName):
  global AdminConfig

  channelService=AdminConfig.list('TransportChannelService', appServerID)
  tcpChannel=AdminConfig.create('TCPInboundChannel', channelService, [['name', TCPChannelName], ['endPointName', endpointName]])
  sslChannel=AdminConfig.create('SSLInboundChannel', channelService, [['name', SSLChannelName], ['sslConfigAlias', sslProfileName]])
  httpChannel=AdminConfig.create('HTTPInboundChannel', channelService, [['name', HTTPChannelName]])  
  webChannel=AdminConfig.create('WebContainerInboundChannel', channelService , [['name', WebContainerChannelName]])  

  return AdminConfig.create('Chain', channelService, [['name', chainName], ['enable', 'true'], ['transportChannels', [tcpChannel, sslChannel, httpChannel, webChannel]]])



def createChannelChain(appServerID, TCPChannelName, HTTPChannelName, WebContainerChannelName, chainName, endpointName):
  global AdminConfig

  channelService=AdminConfig.list('TransportChannelService', appServerID)
  tcpChannel=AdminConfig.create('TCPInboundChannel', channelService, [['name', TCPChannelName], ['endPointName', endpointName]])
  httpChannel=AdminConfig.create('HTTPInboundChannel', channelService, [['name', HTTPChannelName]])  
  webChannel=AdminConfig.create('WebContainerInboundChannel', channelService , [['name', WebContainerChannelName]])  

  return AdminConfig.create('Chain', channelService, [['name', chainName], ['enable', 'true'], ['transportChannels', [tcpChannel, httpChannel, webChannel]]])

  

def configVirtualHost(cellName, vhName, hostName, portNumber):
   global AdminConfig
  
   found  = 'false'
   cellID = AdminConfig.getid('/Cell:' + cellName + '/')
   vhID   = AdminConfig.getid('/VirtualHost:'+ vhName +'/')


   if vhID == "":
      template=AdminConfig.listTemplates('VirtualHost')
      vhID=AdminConfig.createUsingTemplate('VirtualHost', cellID, [['name', vhName]], template)

   hostAliasList=[[]]
  
   hostAliasList=AdminConfig.showAttribute(vhID,'aliases')[1:len(hostAliasList)-1].split(" ")
      
   for hostAlias in hostAliasList:
   
       if hostAlias == "":
         continue

       portNm = AdminConfig.showAttribute(hostAlias, 'port')
       hostNm = AdminConfig.showAttribute(hostAlias, 'hostname')

       if hostNm == hostName and portNm == portNumber:
         found = 'true'
         break
   
   if found != 'true':
     #*******************************************************************************
     #* Create HostAlias
     #*******************************************************************************
     print 'creating alias for port ' + portNumber
     hostAliasID=AdminConfig.create('HostAlias',vhID, [['hostname', hostName], ['port', portNumber]])

 

def removeVirtualHost(cell, virtualHostName, failonerror='false'):
   global AdminConfig

   cellId = AdminConfig.getid("/Cell:"+cell+"/")

   if not cellId:
      raise Exception, "Node " + node + " not found"

   vh = find(cellId, 'VirtualHost', 'name', virtualHostName)

   if vh:
	  AdminConfig.remove(vh)
   else:
      if failonerror == 'true':
         raise Exception, "Virtual Host " + virtualHostName + " not found"
      else:
         print "Warning: Virtual Host " + virtualHostName + " not found"



def removeSSLConfig(cell, configName, failonerror='false'):
   global AdminConfig

   sec = AdminConfig.getid("/Cell:"+cell+"/Security:/")

   if not sec:
      raise Exception, "Unable to get Security configuration for cell " + cell + "."

   ssl = find(sec, 'SSLConfig', 'alias', configName)

   if ssl:
	  AdminConfig.remove(ssl)
   else:
      if failonerror == 'true':
         raise Exception, "SSL Config " + configName + " not found"
      else:
         print "Warning: SSL Config " + configName + " not found"


def removeEndpoint(cell, node, endpointName, failonerror='false'):
   global AdminConfig

   nodeId   = getId(cell,node)

   if not nodeId:
      raise Exception, "Node " + node + " not found"

   endpoint = find(nodeId, 'NamedEndPoint', 'endPointName', endpointName)

   if endpoint:
	  AdminConfig.remove(endpoint)
   else:
      if failonerror == 'true':
         raise Exception, "Endpoint " + endpointName + " not found"
      else:
         print "Warning: Endpoint " + endpointName + " not found"



def removeTransportChannel(cell, node, server, name, failonerror='false'):
   global AdminConfig

   serverId  = getId(cell,node,server)

   if not serverId:
      raise Exception, "Server " + server + " not found"

   transport = find(serverId, 'TransportChannel', 'name', name)

   if transport:
	  AdminConfig.remove(transport)
   else:
      if failonerror == 'true':
         raise Exception, "Transport Channel " + name + " not found"
      else:
         print "Warning: Transport Channel " + name + " not found"


def removeTransportChain(cell, node, server, name, failonerror='false'):
   global AdminConfig

   serverId  = getId(cell,node,server)

   if not serverId:
      raise Exception, "Server " + server + " not found"

   transport = find(serverId, 'Chain', 'name', name)

   if transport:
	  AdminConfig.remove(transport)
   else:
      if failonerror == 'true':
         raise Exception, "Chain " + name + " not found"
      else:
         print "Warning: Chain " + name + " not found"


def removeJAAS(cell, alias, failonerror='false'):
   global AdminConfig

   securityId = AdminConfig.getid("/Cell:" + cell + "/Security:/")

   if not securityId:
      raise Exception, "Unable to get Security configuration for cell " + cell + "."

   jaas = find(securityId, 'JAASAuthData', 'alias', alias)

   if jaas:
	  AdminConfig.remove(jaas)
   else:
      if failonerror == 'true':
         raise Exception, "JAASAuthData " + alias + " not found"
      else:
         print "Warning: JAASAuthData " + alias + " not found"



def getJAAS(cell, alias, failonerror='false'):
   global AdminConfig

   securityId = AdminConfig.getid("/Cell:" + cell + "/Security:/")

   if not securityId:
      raise Exception, "Unable to get Security configuration for cell " + cell + "."

   jaas = find(securityId, 'JAASAuthData', 'alias', alias)

   return jaas


def removeWorkManager(cell, node, server, workManagerName, failonerror='false'):
   global AdminConfig

   serverId = getId(cell, node, server)

   if not serverId:
      raise Exception, "Server " + server + " not found on node " + node

   wm = find(serverId , 'WorkManagerInfo', 'name', workManagerName)

   if wm:
	  AdminConfig.remove(wm)
   else:
      if failonerror == 'true':
         raise Exception, "WorkManager " + workManagerName + " not found"
      else:
         print "Warning: WorkManager " + workManagerName + " not found"


def removeJDBCProvider(cell, node, server, jdbcname, failonerror='false'):
   global AdminConfig

   provider = getId(cell, node, server, 'JDBCProvider', jdbcname)

   if provider:
       AdminConfig.remove(provider)
   else:
      if failonerror == 'true':
         raise Exception, "JDBC Provider " + jdbcname + " not found"
      else:
         print "Warning: JDBC Provider " + jdbcname + " not found"



def removeDataSource(cell, node, server, jdbcProvider, dsname, failonerror='false'):
   cmpName  = dsname + '_CF'
   serverId = getId(cell, node, server)

   if not serverId:
      raise Exception, "Server " + server + " not found on node " + node

   cfactory = find(serverId, 'CMPConnectorFactory', 'name', cmpName)
   if cfactory:
       AdminConfig.remove(cfactory)
   else:
      if failonerror == 'true':
         raise Exception, "CMP Connection Factory " + cmpName + " not found"
      else:
         print "Warning: CMP Connection Factory " + cmpName + " not found"

   dataSource = getId(cell, node, server, 'JDBCProvider:' + jdbcProvider +'/DataSource', dsname)

   if dataSource:
      AdminConfig.remove(dataSource)
   else:
      if failonerror == 'true':
         raise Exception, "Data Source " + dsname + " not found"
      else:
         print "Warning: Data Source " + dsname + " not found"


def removeVariable(cell, node, server, name, failonerror='false'):
    global AdminConfig

    varMapId   = getId(cell, node, server, 'VariableMap')
    varEntries = AdminConfig_list('VariableSubstitutionEntry', varMapId)
    found = 'false'

    for varEntry in varEntries:
        if (AdminConfig.showAttribute(varEntry, 'symbolicName') == name):
            AdminConfig.remove(varEntry)
            found = 'true'
            break

    if found=='false':
       if failonerror == 'true':
          raise Exception, "Variable " + name + " not found"
       else:
          print "Warning: Variable " + name + " not found"


def enableStartupBeansService(cell, node, server):
  serverId = getId(cell, node, server)
  if not serverId:
     raise Exception, "Server not found"
  services = AdminConfig_list("StartupBeansService", serverId)
  service = services[0]
  return AdminConfig.modify(service, '[[enable true]]')

