#!/bin/sh

####################################################################
# Licensed Materials - Property of IBM
# "Restricted Materials of IBM"
# 5724-N93
# (C) Copyright IBM Corp. 2007 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###################################################################

#initialize variables
INSTALLSRC=""; export INSTALLSRC
ERROR="0"; export ERROR
TDWBDIR=""; export TDWBDIR


###### MODIFY THIS IF YOUR MASTER TAG DOES NOT CONTAIN A VALID WAS PROFILE PATH AND CELL NAME ###
WASPROFILEPATH=
TDWB_WAS_CELL=

#The range for return codes for this script is: [21 - 49].
#The reason is explained below for each return code.
#0   - successful
#21   - bad usage
#22   - invalid command line parameters
#23   - TDWB install location doesn't exist
#24   - WAS Profile Path doesn't exist
#25   - WAS Path doesn't exist
#26   - error checking version of WAR module



#This method is used for abnormal termination. The following parameters must be passed
#   reason      -   failure explanation
#   exit code
exitOnError()
{
	exitCode=$1
	shift
	reason=$*
        echo "ERROR: The script ended abnormally. The reason is: $reason"
	echo "The script exit code is $exitCode"
	exit $exitCode
}

#This method is used when the usage option is used. The following parameter must be passed
#   exit code
exitOnUsage()
{
	exitCode=$1
# echo "The script exit code is $exitCode"
	exit $exitCode
}



#MAIN

#Parsing Parameters

while [ $# -gt 0 ]
do
  	CPARM=$1; export CPARM
  	shift

  	case $CPARM in

  	  -usage)
      	echo " The usage of the checkVersion.sh is :"
      	echo " checkVersion.sh"
  	    ERROR="0"
  	    reason="The usage option was used in order to show the script usage."
  	    exitOnUsage $ERROR
  	  ;;

  	  -help)
      	echo " The usage of the checkVersion.sh is :"
      	echo " checkVersion.sh"
            ERROR="0"
  	    reason="The usage option was used in order to show the script usage."
  	    exitOnUsage $ERROR
  	  ;;

  	  *)
  	    echo " The command line is invalid"
  	    echo " Use the -usage or -help option to see the available command line options"
  	    ERROR="22"
  	    reason="invalid command line."
  	    exitOnError $ERROR $reason
  	  ;;

  	esac

done


INSTALLSRC=`pwd`
TDWBDIR=$INSTALLSRC/..
JAVA_DIR=$TDWBDIR/_jvm
MASTERTAG=$TDWBDIR/Install/master.tag



# check the TDWBDIR dir
if [ ! -f "$MASTERTAG" ]
then
    echo " The $TDWBDIR does not seem to be a valid TDWB install location."
    echo " Please check the existence of the file $MASTERTAG"
    ERROR="23"
    reason="wrong install location path."
    exitOnError $ERROR $reason
fi

if [ -z "$WASPROFILEPATH" ]
then
   WASPROFILEPATH=`cat $MASTERTAG | grep TDWB_WAS_PROFILE_PATH | cut -f 2 -d =`; export WASPROFILEPATH
fi

if [ -z "$TDWB_WAS_CELL" ]
then
   TDWB_WAS_CELL=`cat $MASTERTAG | grep TDWB_WAS_CELL | cut -f 2 -d =`; export TDWB_WAS_CELL
fi

if [ -z "$WAS_PATH" ]
then
   WAS_PATH=`cat $MASTERTAG | grep TDWB_WAS_HOME | cut -f 2 -d =`; export WAS_PATH
fi

# check the WASPROFILEPATH dir
if [ ! -d "$WASPROFILEPATH" ]
then
    echo " The master tag in the TDWB install location, ($TDWBDIR/Install/master.tag), does not contain a valid WAS Profile Path."
    echo " Please specify the proper location for the WAS Profile Path installation."
    ERROR="24"
    reason="unexisting was profile path."
    exitOnError $ERROR $reason
fi

# check the WAS_PATH dir
if [ ! -d "$WAS_PATH" ]
then
    echo " The master tag in the TDWB install location, ($TDWBDIR/Install/master.tag), does not contain a valid WAS Path."
    echo " Please specify the proper location for the WAS Path installation."
    ERROR="25"
    reason="unexisting was path."
    exitOnError $ERROR $reason
fi

echo
# RUN JAVA
$WAS_PATH/java/bin/java -jar ./checkVersion.jar "$WASPROFILEPATH" "$TDWB_WAS_CELL"
if [ $? -ne 0 ]   
then
    	ERROR="26"
    	reason="Possible error checking application $SCHEDULER_APPLICATION and module $WAR_MODULE version."
    	exitOnError $ERROR $reason
fi

exit 0

